class XmlInsertionOptions(object):
    APPEND_CHILD = 'AppendChild'
    PREPEND_CHILD = 'PrependChild'
    APPEND_SIBLING = 'AppendSibling'
    PREPEND_SIBLING = 'PrependSibling'


__all__ = ['XmlInsertionOptions']
